#include <ostream.h>
#include "SigsMessagesMetaData.h"


// This file is used to handle SIGS network messages.
// It describes the packet header and functions to
// retrieve meta data format info for the packet of
// that type, or to format a new packet of that type.



// Array describing the data section format of all SIGS messages
//extern const MessageDataFormat dataFormat[];
//extern const int numSigsMessages;


// Message header used by all SIGS messages
struct MessageHeader
{
	int length;
	int messageType;
	int flags;
};



// Returns a pointer to the meta data describing the message of
// the given type. If no meta data is found, a NULL pointer is returned
// Note: Uses binary search to locate the meta data
const MessageDataFormat * FindMessageDataFormat(int messageType);

// Message packing function
//  - returns number of bytes in message
int FormatMessage(void *messageBuffer, int maxSize, int messageType, ...);

// Debug functions
// Unpacks and displays the fields in the message
void DumpHumanReadableMessage(ostream &outStream, void *messageBuffer);

// Message sending function
// - sends the message on the specified socket
// - returns the socket send return code
int SendMessage(int sock, void *messageBuffer);


